Title:          Adventuring! Character Creation
Description:    Creating characters for the Adventuring! campaign.
Footer:         Numenera, the Cypher System, No Thank You, Evil!, Invisible Sun, and their respective logos are
                trademarks of Monte Cook Games, LLC in the U.S.A. and other countries. All Monte Cook Games
                characters and character names, and the distinctive likenesses thereof, are trademarks of Monte
                Cook Games, LLC. Content derived from Monte Cook Games publications is © 2013-2022 Monte Cook
                Games, LLC. <a href="/cypher/fan-use-policy">Full Disclaimer</a>.

# Adventuring! Character Creation

Characters are built by a simple statement that describes them --- *NAME is a [adjective] [adjective] [noun] who [verbs]* --- built from words and phrases from the Cypher System: descriptors, types, and foci. Adjectives are
[Descriptors](#descriptors), and PCs get two; one general descriptor and one racial descriptor (or two general descriptors for
humans). Nouns are [Types](#types), similar to character classes, and verbs are [Foci](#foci).

Chapter 4 of the *Cypher System Rulebook* details character creation, with description of the mechanical elements, and a
small sidebar summarizing the steps to take to create a character. The majority of this information is covered in the
[Cypher System Reference Document (SRD)](https://callmepartario.github.io/og-csrd/), though the core rulebook presents
it in a bit more descriptive fashion.

We are also utilizing the following optional rules, noted here since they affect character creation and advancement:

* [Spellcasting](https://callmepartario.github.io/og-csrd/#optional-rule-spellcasting)
* [Two Descriptors](https://callmepartario.github.io/og-csrd/#variant-rule-two-descriptors)

## Sources

The majority of the options below are found, and best described, in the *Cypher System Rulebook*, with an open gaming
version available via the Cypher SRD. Most others come from *Godforsaken*, also available at the SRD, and *Path of the
Planebreaker* and *Planar Character Options*, referenced (but not described) at the SRD link, also from Monte Cook
Games, may also be of interest. Anything homebrew we will write up and include here.

I skipped listing a lot of the core content, because there's no point in repeating that everything in the core book/SRD
are fair game --- the exception to this are the foci, which are tailored below.

## Types

The four [types (SRD)](https://callmepartario.github.io/og-csrd/#chapter-5-type) are all relevant to the game. [Fantasy
Character Options (SRD)](https://callmepartario.github.io/og-csrd/#fantasy-character-options), from *Godforsaken*, has
suggestions on how to build all of the classic classes via the type system. For example, a barbarian would likely be a
Warrior that takes the Rages ability, but a bard might easily be an Explorer or a Speaker, depending on the concept and
desired abilities.

[Flavors (SRD)](https://callmepartario.github.io/og-csrd/#chapter-6-flavor) are not dissimilar to the idea of
subclassing. A spellblade may be a Warrior with the Magic flavor, for example.

*Godforsaken* has the best guidance here, though plenty of ideas are presented in the core book/SRD. Ask bss if you have
questions, especially if you feel there is a concept or specific implementation that doesn't fit within the out of the
box system, since it is fairly flexible.

## Descriptors

Descriptors are the adjectives for the character, describing how the character goes about their business. All of the
[Descriptors (SRD)](https://callmepartario.github.io/og-csrd/#chapter-7-descriptor) in the core book are fair game, as
are the [Fantasy Species Descriptors
(SRD)](https://callmepartario.github.io/og-csrd/#choose-descriptors-fantasy-species), originally from *Godforsaken* and
the fantasy setting section of the core book.

Adventuring! uses the "Two Descriptors" variant rule as described under [Species as
Descriptor](https://callmepartario.github.io/og-csrd/#species-as-descriptor).

### Faerûnian Races

The *Forgotten Realms Campaign Setting (3e)* presents a number of racial options for D&D characters. For a character
that hews a bit closer to the Forgotten Realms line, you can apply these conversions:

* **Humans:** take two non-species descriptors.
* **Dwarves:**
    * **Gold:** as the Cypher dwarf, except as follows:
        * **Skill:** Gold dwarves receive training against the bizarre creatures of the Underdark. Replace the practice
          in axes and skill in shaping and mining stone with a skill against abberations; tasks involving
          opposing or attacking abberations are eased one step.
    * **Gray:** as the Cypher dwarf, except as follows:
        * **Inability:** You have difficulty relating to other species due to your withdrawn and guarded nature. Any
          task involving social interaction with them is hindered.
        * **Inability:** Generations in the Underdark have saddled you with light sensitivity. Tasks involving seeing in
          bright sunlight are hindered.
        * **Darkvision:** You can see in the dark up to 120 feet.
        * **Skill:** The Underdark has led your people to stealth. Tasks involving stealth are eased one step.
    * **Shield:** as the Cypher dwarf.
* **Elves:**
    * **Drow:** as the Cypher elf, except as follows:
        * **Weapons:** replace the practice in a bow, and starting equipment, with that of a rapier or shortsword.
        * **Stealth:** the specialization in stealth tasks applies to cave areas rather than natural woodland.
        * **Inability:** Generations in the Underdark have saddled you with light sensitivity. Tasks involving seeing in
          bright sunlight are hindered.
        * **Darkvision:** You can see in the dark up to 120 feet.
    * **Moon:** as the Cypher elf.
    * **Sun:** as the Cypher elf, except as follows:
        * **Studious:** apply the +2 bonus to your Intellect Pool instead of your Speed Pool.
    * **Wild:** as the Cypher elf.
    * **Wood:** as the Cypher elf.
* **Gnomes:**
    * **Deep:** as the Cypher gnome, except as follows:
        * **Inability:** svirfneblin are suspicious to a fault. Tasks involving positive or pleasant social interaction
          are hindered.
        * **Darkvision:** You can see in the dark up to 120 feet.
    * **Rock:** as the Cypher gnome.
* **Half-elves:** take two non-species descriptors as per human, providing yourself with some elven features.
* **Half-orcs:** as the Cypher half-giant, except as follows:
    * **Tough:** the bonus to your Might Pool is +2, not +4.
    * **Not Too Large:** you do not suffer the hindrance to initiative, stealth, or fine manipulation.
* **Halflings:**
    * **Ghostwise:** as the Cypher halfling, except as follows:
        * **Speak Without Sound:** you can communicate telepathically with any one creature within 20 feet, as long as
          they share a common language.
        * **Not As Lucky:** you do not receive the +3 advantage when spending 1 XP to reroll.
    * **Lightfoot:** as the Cypher halfling.
    * **Strongheart:** as the Cypher halfling, except as follows:
        * **Small Yet Strong:** you are still small, but do not suffer the hindrance to Might-based tasks.
        * **Not As Lucky:** you do not receive the +3 advantage when spending 1 XP to reroll.
* **Planetouched:**
    * **Aasimar:** as the Cypher helborn, except as follows:
        * **Of the Heavens:** replace the underworld, evil, etc. themes with that of a celestial.
        * **Not Tainted:** You are not trained in tasks related to the lore of the underworld.
        * **Of A Safer Plane:** You do not have +2 to Armor against damage from fire.
        * **Not Innerly Evil:** You do not suffer from the chance of losing control.
        * **Trustworthy:** Your celestial nature makes people trust you. Replace the hindrance to tasks to persuade or
          deceive with training in doing so.
    * **Genasi:** as the Cypher helborn, except as follows:
        * **Of an Element:** replace the underworld, evil, etc. themes with that of your element.
        * **Forces of Nature:** replace the +2 to your Intellect Pool with a +2 to your Might Pool for fire or earth, or
          Speed Pool for air or water genasi.
        * **Not Tainted:** You are not trained in tasks related to the lore of the underworld.
        * **Elementally Resistant:** replace the +2 to Armor against damage from fire with that of your element.
        * **Nature's Fury:** as **Inner Evil**, but it is more accidental than inherent evil; you do not suffer the -1
          penalty to all rolls following the fury.
    * **Tiefling:** as the Cypher helborn.

## Foci

Foci are the possible verb-phrases that describe what the character does and is good at, beyond the basics from their
type. Most but not all foci in the core book are suitable for the campaign. The following is a mostly vetted list of
core and *Godforsaken* foci (others are negotiable):

* *Core:* Abides in Stone; Bears A Halo of Fire; Blazes With Radiance; Builds Robots; Channels Divine Blessings;
  Commands Mental Powers; Consorts With the Dead; Controls Beasts; Crafts Illusions; Crafts Unique Objects; Defends the
  Gate; Defends the Weak; Descends From Nobility; Entertains; Exists In Two Places At Once; Exists Partially Out Of
  Phase; Explores Dark Places; Fights Dirty; Fights With Panache; Focuses Mind Over Matter; Howls At The Moon; Hunts;
  Infiltrates; Keeps A Magic Ally; Leads; Lives in the Wilderness; Looks For Trouble; Masters Defense; Masters Spells;
  Masters the Swarm; Masters Weaponry; Moves Like a Cat; Murders; Needs No Weapon; Never Says Die; Performs Feats of
  Strength; Rages; Rides the Lightning; Sees Beyond; Sailed Beneath the Jolly Roger; Scavenges; Sees Beyond; Separates
  Mind From Body; Shepherds the Community; Shepherds Spirits; Slays Monsters; Solves Mysteries; Speaks For the Land;
  Stands Like a Bastion; Throws With Deadly Accuracy; Thunders; Travels Through Time; Was Foretold; Wears A Sheen of
  Ice; Wields Two Weapons At Once; Works Miracles; Works the Back Alleys
* *Godforsaken:* Takes Animal Shape; Uses Wild Magic; Walks the Wild Woods; Wields an Enchanted Weapon

These Foci and more can be found at [Focus (SRD)](https://callmepartario.github.io/og-csrd/#chapter-8-focus).

For the Forgotten Realms feel, I recommend simply reading the descriptions of the classes and prestige classes in the
*Forgotten Realms Campaign Setting (3e)* and applying their flavor thematically. Again, the core classes can generally
be satisfied by [Fantasy Character Options (SRD)](https://callmepartario.github.io/og-csrd/#fantasy-character-options).
Some of the Forgotten Realms prestige classes are tied to setting lore and may be interesting to emulate, but don't need
any specific conversion beyond selecting appropriate abilities and potentially utilizing the optional spellcasting rule.

## Abilities

Types and foci give access to abilities, depending on the character's tier (level, basically). There's no point in
listing them all, if your choices grant access to the ability, it's in.
